package com.diagbot.facade;

import com.diagbot.dto.RespDTO;
import com.diagbot.entity.MedicalRecord;
import com.diagbot.entity.StrDeathNote;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.StrDeathNoteServiceImpl;
import com.diagbot.vo.str.StrDeathNoteVO;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @Description:
 * @author: cy
 * @time: 2020/9/23 11:39
 */
@Component
public class StrDeathNoteFacade extends StrDeathNoteServiceImpl {

    @Autowired
    private MedicalRecordFacade medicalRecordFacade;

    public RespDTO<StrDeathNoteVO> sendDeathNoteInfos(StrDeathNote strDeathNote) {

        try {
            //根据病历id、病历模版id和记录时间查询文书记录id
            MedicalRecord medicalRecord = medicalRecordFacade.lambdaQuery()
                    .like(MedicalRecord::getBehospitalCode, strDeathNote.getBehospitalCode())
                    .eq(MedicalRecord::getModeId, 24)//死亡记录的病历模版id为24，写死
                    .one();
            //病历id合法性校验
            if(medicalRecord == null){
                throw new CommonException(CommonErrorCode.NOT_EXISTS);
            }
            strDeathNote.setRecId(medicalRecord.getRecId());
            //将实体类字段转json
            ObjectMapper objectWriter = new ObjectMapper();
            String strResult = objectWriter.writeValueAsString(strDeathNote);
            strDeathNote.setWholeData(strResult);
            //修改或更新表中记录
            boolean saveOrUpdate = this.saveOrUpdate(strDeathNote);
            return saveOrUpdate == true? RespDTO.onSuc("操作正常！") : RespDTO.onError("保存记录失败！");
        } catch (JsonProcessingException e) {
            throw new CommonException(CommonErrorCode.INSERT_DATA_FAILED);
        }
    }
}
