package com.diagbot.facade;

import com.diagbot.dto.RespDTO;
import com.diagbot.entity.MedicalRecord;
import com.diagbot.entity.StrLeaveHospital;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.StrLeaveHospitalServiceImpl;
import com.diagbot.vo.str.StrLeaveHospitalVO;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @Description:
 * @author: cy
 * @time: 2020/9/23 11:39
 */
@Component
public class StrLeaveHospitalFacade extends StrLeaveHospitalServiceImpl {

    @Autowired
    private MedicalRecordFacade medicalRecordFacade;

    public RespDTO<StrLeaveHospitalVO> sendLeaveHospitalInfos(StrLeaveHospital strLeaveHospital) {

        try {
            //根据病历id、病历模版id和记录时间查询文书记录id
            MedicalRecord medicalRecord = medicalRecordFacade.lambdaQuery()
                    .like(MedicalRecord::getBehospitalCode, strLeaveHospital.getBehospitalCode())
                    .eq(MedicalRecord::getModeId, 5)//出院小结的病历模版id为5，写死
                    .one();
            //病历id合法性校验
            if(medicalRecord == null){
                throw new CommonException(CommonErrorCode.NOT_EXISTS);
            }
            strLeaveHospital.setRecId(medicalRecord.getRecId());
            //将实体类字段转json
            ObjectMapper objectWriter = new ObjectMapper();
            String strResult = objectWriter.writeValueAsString(strLeaveHospital);
            strLeaveHospital.setWholeData(strResult);
            //修改或更新表中记录
            boolean saveOrUpdate = this.saveOrUpdate(strLeaveHospital);
            return saveOrUpdate == true? RespDTO.onSuc("操作正常！") : RespDTO.onError("保存记录失败！");
        } catch (JsonProcessingException e) {
            throw new CommonException(CommonErrorCode.INSERT_DATA_FAILED);
        }
    }
}
