package com.diagbot.facade;


import com.diagbot.dto.RespDTO;
import com.diagbot.entity.MedicalRecord;
import com.diagbot.entity.StrTransferOutNote;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.StrTransferOutNoteServiceImpl;
import com.diagbot.vo.str.StrTransferOutNoteVO;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @Description:
 * @author: cy
 * @time: 2020/9/23 11:39
 */
@Component
public class StrTransferOutNoteFacade extends StrTransferOutNoteServiceImpl {

    @Autowired
    private MedicalRecordFacade medicalRecordFacade;

    public RespDTO<StrTransferOutNoteVO> sendTransferOutNoteInfos(StrTransferOutNote strTransferOutNote) {

        try {
            //根据病历id、病历模版id和记录时间查询文书记录id
            MedicalRecord medicalRecord = medicalRecordFacade.lambdaQuery()
                    .like(MedicalRecord::getBehospitalCode, strTransferOutNote.getBehospitalCode())
                    .eq(MedicalRecord::getModeId, 27)//转出记录的病历模版id为27，写死
                    .eq(MedicalRecord::getRecDate, strTransferOutNote.getRecDate())
                    .one();
            //病历id合法性校验
            if(medicalRecord == null){
                throw new CommonException(CommonErrorCode.NOT_EXISTS);
            }
            strTransferOutNote.setRecId(medicalRecord.getRecId());
            //将实体类字段转json
            ObjectMapper objectWriter = new ObjectMapper();
            String strResult = objectWriter.writeValueAsString(strTransferOutNote);
            strTransferOutNote.setWholeData(strResult);
            //修改或更新表中记录
            boolean saveOrUpdate = this.saveOrUpdate(strTransferOutNote);
            return saveOrUpdate == true? RespDTO.onSuc("操作正常！") : RespDTO.onError("保存记录失败！");
        } catch (JsonProcessingException e) {
            throw new CommonException(CommonErrorCode.INSERT_DATA_FAILED);
        }

    }
}
